@@ -6,7 +6,7 @@ import os
 
 dirs = appdirs.AppDirs("canvaslms", "dbosk@kth.se")
 
-def update_credentials_in_keyring(config, canvas, args):
+def login_command(config, canvas, args):
   """Guides the user to update credentials"""
 
   print("Enter the hostname for Canvas, "
@@ -30,13 +30,14 @@ in your browser. Scroll down to approved integrations and click the
     keyring.set_password("canvaslms", "token", token)
   except:
     canvaslms.cli.warn(f"You don't have a working keyring. "
-      "Will write hostname and token written to config file "
-      "{args.config_file}.")
+                       f"Will write hostname and token to config file "
+                       f"{args.config_file}.")
 
     config["canvas"]["host"] = hostname
     config["canvas"]["access_token"] = token
 
     canvaslms.cli.update_config_file(config, args.config_file)
+
 def load_credentials(config):
   """Load credentials from keyring, environment or config dictionary"""
   try:
@@ -65,27 +66,27 @@ def add_command(subp):
   """Adds the login command to argparse parser"""
   login_parser = subp.add_parser("login",
     help="Manage login credentials",
-    description="""
+    description=f"""
 Manages the user's Canvas login credentials. There are three ways to supply the 
 login credentials, in order of priority:
 
 1) Through the system keyring: Just run `canvaslms login` and you'll be guided 
-  to enter the credentials (server name and token) and they will be stored in 
-  the keyring.
+   to enter the credentials (server name and token) and they will be stored in 
+   the keyring.
 
 2) Through the environment: Just set the environment variables CANVAS_SERVER 
-  and CANVAS_TOKEN.
+   and CANVAS_TOKEN.
 
 3) Through the configuration file: Just write
 
-      {
-        "canvas": {
+      {{
+        "canvas": {{
           "host": "the actual hostname",
           "access_token": "the actual token"
-        }
-      }
+        }}
+      }}
 
-  to the file """ + dirs.user_config_dir + """/config.json (default, or use the 
-  -f option, see `canvaslms -h`).
+   to the file {dirs.user_config_dir}/config.json (default, or use the -f 
+   option, see `canvaslms -h`).
 """)
-  login_parser.set_defaults(func=update_credentials_in_keyring)
+  login_parser.set_defaults(func=login_command)
